@@ -1,12 +1,8 @@
-from abc import ABC
+from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from typing import Any
 
-from linkml_runtime import SchemaView
-from linkml_runtime.utils.yamlutils import YAMLRoot
-
-from linkml_transformer.datamodel.transformer_model import \
-    TransformationSpecification
+from linkml_transformer.datamodel.transformer_model import TransformationSpecification
 
 
 @dataclass
@@ -19,7 +15,6 @@ class Importer(ABC):
     An example importer would be sssom.
     """
 
-
     @abstractmethod
     def import_specification(self, input: Any) -> TransformationSpecification:
         """
